**Introduction**

A small test package providing function which counts a number of one time appearing characters in a string or file given.

**Features**
- You can use command line interface in a usual Python way:

\>>> python char_count.py [-h] [-f FILE] [-s STRING]
- Or you can simply *import* char_count() function to your project
